/** 
 * Copyright (C) 2013 Quan Wang <wangq10@rpi.edu>
 * Signal Analysis and Machine Perception Laboratory
 * Department of Electrical, Computer, and Systems Engineering
 * Rensselaer Polytechnic Institute, Troy, NY 12180, USA
 */

/**
 * This class evaluates the precision, recall, accuracy 
 * and F1-measure of the binary classification by Fisher LDA
 * 
 * @author Quan Wang
 *
 */

public class BinaryEvaluation {
	
	int[] labels; // resulting labels
	double precision;
	double recall;
	double accuracy;
	double F1;
	
	// evaluate the resulting labels given the truth labels (if not given, will not evaluate)
	public void evaluate(int[] truth)
	{
		if(truth==null)
		{
			System.out.println("Ground truth labels are not given, thus evaluation is not performed. ");
			precision=Double.NaN;
			recall=Double.NaN;
			accuracy=Double.NaN;
			F1=Double.NaN;
			return;
		}
		
		double tp=0;
		double fn=0;
		double fp=0;
		double tn=0;
		
		for(int i=0;i<truth.length;i++)
		{
			if(truth[i]==1 && labels[i]==1) tp++;
			else if(truth[i]==1 && labels[i]==0) fn++;
			else if(truth[i]==0 && labels[i]==1) fp++;
			else if(truth[i]==0 && labels[i]==0) tn++;
		}
		
		precision=tp/(tp+fp+Double.MIN_VALUE);
	    recall=tp/(tp+fn+Double.MIN_VALUE);
	    accuracy=(tp+tn)/(tp+tn+fp+fn+Double.MIN_VALUE);
	    F1=2*precision*recall/(precision+recall+Double.MIN_VALUE);
	}
	
	// print evaluation results
	public void print()
	{
		System.out.println("Testing results:");
		System.out.println("precision: "+precision);
		System.out.println("recall: "+recall);
		System.out.println("accuracy: "+accuracy);
		System.out.println("F1-measure: "+F1);
		System.out.print("\n");
	}

	public int[] getLabels() {
		return labels;
	}

	public void setLabels(int[] labels) {
		this.labels = labels;
	}

	public double getPrecision() {
		return precision;
	}

	public void setPrecision(double precision) {
		this.precision = precision;
	}

	public double getRecall() {
		return recall;
	}

	public void setRecall(double recall) {
		this.recall = recall;
	}

	public double getAccuracy() {
		return accuracy;
	}

	public void setAccuracy(double accuracy) {
		this.accuracy = accuracy;
	}

	public double getF1() {
		return F1;
	}

	public void setF1(double f1) {
		F1 = f1;
	}
	
	
}
