/** 
 * Copyright (C) 2013 Quan Wang <wangq10@rpi.edu>
 * Signal Analysis and Machine Perception Laboratory
 * Department of Electrical, Computer, and Systems Engineering
 * Rensselaer Polytechnic Institute, Troy, NY 12180, USA
 */

import java.io.File;
import java.io.IOException;
import org.apache.commons.io.FileUtils;

/**
 * This class is for the binary Fisher LDA model
 * 
 * @author Quan Wang
 *
 */

public class FisherLdaModel {

	double[] weights;
	double threshold;
	double[] projectedFeatures;

	public FisherLdaModel(double[] weights, double threshold,double[] projectedFeatures) {
		this.weights = weights;
		this.threshold = threshold;
		this.projectedFeatures = projectedFeatures;
	}

	// show parameters
	public void print()
	{
		System.out.println("Fisher LDA model:");
		System.out.print("weights: ");
		for(int i=0;i<weights.length;i++)
		{
			System.out.print(weights[i]+"  ");
		}
		System.out.print("\n");
		System.out.println("threshold: "+threshold);
		System.out.print("projected features: ");
		for(int i=0;i<projectedFeatures.length;i++)
		{
			System.out.print(projectedFeatures[i]+"  ");
		}
		System.out.print("\n\n");
	}

	// save the fisher model to a json file
	public void saveModelToJson(String jsonFileName)
	{
		String text="{";

		text+="\"weights\": [";
		for(int i=0;i<weights.length;i++)
		{
			text+=weights[i];
			if(i<weights.length-1)
			{
				text+=", ";
			}
			else
			{
				text+="], ";
			}
		}
		text+="\"threshold\": "+threshold;
		
		text+="}";

		try
		{
			FileUtils.writeStringToFile(new File(jsonFileName), text);

			System.out.println("Binary Fisher LDA model saved to file: "+jsonFileName);
			System.out.print("\n");
		}
		catch(IOException e)
		{}
	}
	
	
	public double[] getWeights() {
		return weights;
	}
	public void setWeights(double[] weights) {
		this.weights = weights;
	}
	public double getThreshold() {
		return threshold;
	}
	public void setThreshold(double threshold) {
		this.threshold = threshold;
	}

	public double[] getProjectedFeatures() {
		return projectedFeatures;
	}

	public void setProjectedFeatures(double[] projectedFeatures) {
		this.projectedFeatures = projectedFeatures;
	}
	
}
