/** 
 * Copyright (C) 2013 Quan Wang <wangq10@rpi.edu>
 * Signal Analysis and Machine Perception Laboratory
 * Department of Electrical, Computer, and Systems Engineering
 * Rensselaer Polytechnic Institute, Troy, NY 12180, USA
 */

import Jama.*;

/**
 * This class is for the predicting/testing of binary Fisher LDA
 * If truth labels are not available, just use null for truth, and evaluation will not be performed
 * 
 * @author Quan Wang
 *
 */

public class FisherPredict {
	
	// predicting/testing
	public static BinaryEvaluation predict(double[][] features, FisherLdaModel model, int[] truth)
	{
		BinaryEvaluation eva=new BinaryEvaluation();
		
		Matrix fMatrix=new Matrix(features);
		Matrix wVector=new Matrix(model.weights,model.weights.length);
		Matrix fpVector=fMatrix.times(wVector);
		
		int[] labels=new int[features.length];
		for(int i=0;i<labels.length;i++)
		{
			if(fpVector.get(i, 0)>model.threshold)
			{
				labels[i]=1;
			}
			else
			{
				labels[i]=0;
			}
		}
		
		eva.setLabels(labels);

		eva.evaluate(truth);
		
		return eva;
	}

}
